#!/bin/sh -e

. /usr/share/debconf/confmodule
db_version 2.0
db_capb backup

terms=Zekr-Quran-Trans

errmsg()
{
    echo >&2 ''
    echo >&2 "$@"
    echo >&2 "try 'dpkg-reconfigure debconf' to select a frontend other than noninteractive"
    echo >&2 ''
}

db_get quran-translations-ur/accepted-$terms
if [ "$RET" = "true" ]; then
    echo "$terms terms has already been accepted" >&2
    exit 0
fi

# facilitate backup capability per debconf-devel(7)
STATE=1
while true; do
    case "$STATE" in
    0)  # ensure going back from terms presentment is harmless
        STATE=1 
        continue
        ;;   
    1)  # present terms
        db_fset quran-translations-ur/present-$terms-disclaimer seen false
        if ! db_input critical quran-translations-ur/present-$terms-disclaimer ; then
            errmsg "$terms terms could not be presented"
	    exit 2
        fi
        db_fset quran-translations-ur/present-$terms-copyright seen false
        if ! db_input critical quran-translations-ur/present-$terms-copyright ; then
            errmsg "$terms terms could not be presented"
        exit 2
        fi        
        db_fset quran-translations-ur/accepted-$terms seen false
        if ! db_input critical quran-translations-ur/accepted-$terms ; then
            errmsg "$terms agree question could not be asked"
	    exit 2
        fi
        ;;      
    2)  # determine users' choice
        db_get quran-translations-ur/accepted-$terms
        if [ "$RET" = "true" ]; then
	    # terms accepted
            exit 0
        fi
        # error on decline terms (give user chance to back up)
        db_input critical quran-translations-ur/error-$terms
        ;;      
    3)  # user has confirmed declining terms
        echo "user did not accept the $terms terms" >&2
        exit 1
        ;;   
    *)  # unknown state
        echo "$terms terms state unknown: $STATE" >&2
        exit 2
        ;;   
    esac
    if db_go; then
        STATE=$(($STATE + 1))
    else
        STATE=$(($STATE - 1))
    fi
done
 


# proper exit (0 or 1) above
errmsg "$terms terms could not be presented / was not accepted"
exit 2
